# Workaround underlinking issue
%define _disable_ld_no_undefined 1

%define builddocs 1

%define major     %{version}
%define libname   %mklibname %{name} %{major}
%define libname_c %mklibname %{name}_c++ %{major}
%define devname   %mklibname %{name} -d

Name:           nco
Version:        5.2.9
Release:        %mkrel 1
Summary:        Suite of programs for manipulating NetCDF/HDF4 files
License:        BSD-3-Clause
Group:          Sciences/Other
URL:            https://nco.sourceforge.net/
Source0:        https://github.com/nco/nco/archive/%{version}/%{name}-%{version}.tar.gz
Patch0:         nco-install_C_headers.patch

BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gawk
%ifarch %java_arches
BuildRequires:  antlr-tool
BuildRequires:  antlr-C++
%endif
BuildRequires:  chrpath
BuildRequires:  texinfo
BuildRequires:  gsl-devel
BuildRequires:  netcdf-devel
BuildRequires:  udunits2-devel
%if 0%{?builddocs}
BuildRequires:  texinfo-tex
%endif

%description
The netCDF Operators, NCO, are a suite of command line programs known
as operators.  The operators facilitate manipulation and analysis of
self-describing data stored in the freely available netCDF and HDF
formats (http://www.unidata.ucar.edu/packages/netcdf and
http://hdf.ncsa.uiuc.edu, respectively).  Each NCO operator (e.g.,
ncks) takes netCDF or HDF input file(s), performs an operation (e.g.,
averaging, hyperslabbing, or renaming), and outputs a processed netCDF
file.  Although most users of netCDF and HDF data are involved in
scientific research, these data formats, and thus NCO, are generic and
are equally useful in fields from agriculture to zoology.  The NCO
User's Guide illustrates NCO use with examples from the field of
climate modeling and analysis.
The NCO homepage is http://nco.sourceforge.net/.

%package -n %{libname}
Summary:        Main library for NCO
Group:          System/Libraries

%description -n %{libname}
This package contains the NCO main library.

%package -n %{libname_c}
Summary:        C++ library for NCO
Group:          System/Libraries

%description -n %{libname_c}
This package contains the NCO C++ library.

%package -n %{devname}
Summary:        Development files for NCO
Group:          Development/C
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libname_c} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains the NCO header and development files.

%prep
%autosetup -p1

%build
export CPPFLAGS=-I%{_includedir}/udunits2
%configure \
        HOST=%{_vendor} \
%ifarch %java_arches
        --enable-ncap2 \
%else
        --disable-ncap2 \
%endif
        --disable-static \
        --disable-dependency-tracking \
        --enable-nco_cplusplus \
        --with-hdf5-plugin-path=%{_libdir}/hdf5/plugin \
        --includedir=%{_includedir}/nco
%make_build

%if 0%{?builddocs}
make -C doc html pdf
%endif

%install
%make_install

find %{buildroot} -name '*.la' -delete

# Ignore non-ELF files
chrpath -d -k %{buildroot}%{_bindir}/* || :

%files
%license doc/LICENSE
%doc README* doc/rtfm.txt doc/nco.html doc/nco.pdf doc/nco.css
%doc doc/index.shtml doc/TODO doc/ChangeLog doc/nco.png doc/nco_news.shtml
%doc doc/nsf.png
%ifarch %java_arches
%{_bindir}/ncap2
%endif
%{_bindir}/ncatted
%{_bindir}/ncbo
%{_bindir}/ncchecker
%{_bindir}/ncclimo
%{_bindir}/ncdiff
%{_bindir}/ncea
%{_bindir}/ncecat
%{_bindir}/nces
%{_bindir}/ncflint
%{_bindir}/ncks
%{_bindir}/ncpdq
%{_bindir}/ncra
%{_bindir}/ncrcat
%{_bindir}/ncremap
%{_bindir}/ncrename
%{_bindir}/ncwa
%{_bindir}/ncz2psx
%{_mandir}/man1/ncap2.1*
%{_mandir}/man1/ncatted.1*
%{_mandir}/man1/ncbo.1*
%{_mandir}/man1/ncchecker.1*
%{_mandir}/man1/ncclimo.1*
%{_mandir}/man1/ncecat.1*
%{_mandir}/man1/nces.1*
%{_mandir}/man1/ncflint.1*
%{_mandir}/man1/ncks.1*
%{_mandir}/man1/nco.1*
%{_mandir}/man1/ncpdq.1*
%{_mandir}/man1/ncra.1*
%{_mandir}/man1/ncrcat.1*
%{_mandir}/man1/ncremap.1*
%{_mandir}/man1/ncrename.1*
%{_mandir}/man1/ncwa.1*
%{_mandir}/man1/ncz2psx.1*
%{_infodir}/*

%files -n %{libname}
%{_libdir}/libnco-%{major}.so

%files -n %{libname_c}
%{_libdir}/libnco_c++-%{major}.so

%files -n %{devname}
%{_includedir}/nco/
%{_libdir}/libnco.so
%{_libdir}/libnco_c++.so


%changelog
* Sat Oct 19 2024 daviddavid <daviddavid> 5.2.9-1.mga10
+ Revision: 2108150
- new version: 5.2.9

* Tue Sep 03 2024 daviddavid <daviddavid> 5.2.8-1.mga10
+ Revision: 2092856
- new version: 5.2.8

* Sat Jul 27 2024 daviddavid <daviddavid> 5.2.7-1.mga10
+ Revision: 2082638
- new version: 5.2.7

* Sun Jun 23 2024 daviddavid <daviddavid> 5.2.6-1.mga10
+ Revision: 2076244
- new version: 5.2.6

* Thu Jun 20 2024 daviddavid <daviddavid> 5.2.5-1.mga10
+ Revision: 2075804
- new version: 5.2.5

* Wed Apr 17 2024 daviddavid <daviddavid> 5.2.4-1.mga10
+ Revision: 2058391
- new version: 5.2.4

* Mon Apr 08 2024 daviddavid <daviddavid> 5.2.3-1.mga10
+ Revision: 2055346
- new version: 5.2.3

* Tue Mar 26 2024 daviddavid <daviddavid> 5.2.2-1.mga10
+ Revision: 2052282
- new version: 5.2.2

* Tue Feb 20 2024 daviddavid <daviddavid> 5.2.1-1.mga10
+ Revision: 2042604
- new version: 5.2.1

* Sun Feb 18 2024 daviddavid <daviddavid> 5.2.0-1.mga10
+ Revision: 2042264
- new version: 5.2.0

* Thu Nov 09 2023 daviddavid <daviddavid> 5.1.9-1.mga10
+ Revision: 2005349
- new version: 5.1.9

* Wed Sep 20 2023 daviddavid <daviddavid> 5.1.8-1.mga10
+ Revision: 1988455
- new version: 5.1.8

* Mon Aug 28 2023 daviddavid <daviddavid> 5.1.7-1.mga10
+ Revision: 1980530
- new version: 5.1.7

* Sun May 21 2023 daviddavid <daviddavid> 5.1.6-1.mga9
+ Revision: 1957507
- initial package nco (mga#12846)

